﻿* Encoding: UTF-8.
/******************************************************************************
/*
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*        PLAN NACIONAL PARA LA EVALUACIÓN DE LOS APRENDIZAJES (PLANEA)
/*                    TERCER GRADO DE PREESCOLAR (PLANEA 00)
/*
/*                       ****PENSAMIENTO MATEMÁTICO ****
/*
/*                     Ciclo escolar evaluado: 2017 - 2018
/*_____________________________________________________________________________
/*
/*
/*      SINTAXIS PARA ETIQUETAR LA BASE DE DATOS DE ALUMNOS DE PENSAMIENTO
/*                          MATEMÁTICO EN FORMATO SPSS
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla PLANEA00_2018_Alumnos_PM.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel. 54820900  Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. México. D.F.
/*
/* FECHA DE LIBERACIÓN:  05 DE JULIO 2019
/*
/*  ****************************************************************************/



/***********************************************************************
/*                  Código para etiquetar las variables
/*
/**********************************************************************.
VARIABLE LABELS
       NACIONAL       "Variable auxiliar para obtener promedios nacionales"
       ALUMNO         "Identificador del alumno"
       ESCUELA        "Identificador de la escuela"
       ID_SERV        "Tipo de escuela (identificador numérico)"
       SERV           "Tipo de escuela"
       ESTRATO        "Estrato del diseño muestral"
       RURALIDAD      "Rural-Urbano"
       ID_PM_INSTR    "Identificador del cuadernillo de examen de pensamiento matemático"
       SEXO           "Sexo del alumno"
       EDAD_AC        "Edad en años cumplidos estimada a partir del campo EDAD"
       MES_NAC        "Mes de nacimiento del alumno"
       EDAD           "Edad del alumno, al último día de la aplicación de la prueba, estimada a partir del día, mes y año de nacimiento"
       EDAD_ACC       "Edad en años cumplidos por categoría estimada a partir del campo EDAD"
       EDAD_AT        "Edad arriba de la típica estimada a partir del campo EDAD"
       W_FSTUWT       "Peso muestral o ponderador del alumno"
       DOCENTE        "Identificador del docente"
       KMA_1          "Identifica el valor de las monedas."
       KMA_2          "Representa convencionalmente la cantidad de elementos de una colección menor a diez."
       KMA_3          "Resuelve problemas que implican la cuantificación de  una colección representada gráficamente, en un rango de trece a veinte objetos desordenados."
       KMA_4          "Traza en una retícula tres figuras geométricas."
       KMA_5          "Resuelve problemas que implican agregar  menos de 20 elementos a una  colección."
       KMA_6          "Identifica el lugar que ocupa un elemento dentro de una serie ordenada mediante la designación de un número ordinal en un rango del primero al quinto."
       KMA_7          "Identifica cómo se ve un objeto desde diversos puntos espaciales."
       KMB_1          "Identifica entre diversos instrumentos convencionales de medida el adecuado para medir determinada magnitud."
       KMB_2          "Establece relaciones temporales (antes-después-al final)."
       KMB_3          "Elige de entre varias monedas de diferente denominación las equivalentes a un valor dado."
       KMB_4          "Comunica el desplazamiento de un elemento en una representación gráfica, utilizando puntos de referencia y cambios de dirección."
       KMB_5          "Resuelve problemas que implican comparar dos colecciones que no excedan de 10 elementos."
       KMB_6          "Comunica posiciones de un objeto en relación con otro en una representación gráfica utilizando términos que denotan posiciones relativas."
       KMC_1          "Interpreta información de una gráfica."
       KMC_2          "Interpreta información de un cuadro de doble entrada."
       KMC_3          "Construye una figura geométrica al unir  varias figuras geométricas iguales."
       KMC_4          "Completa una figura simétrica en una retícula."
       KMC_5          "Resuelve problemas que implican reunir dos colecciones con menos de 20 elementos."
       KMC_6          "Resuelve problemas que implican igualar dos colecciones que no excedan 10 elementos."
       KMC_7          "Ordena colecciones  con base en su numerosidad, en orden ascendente."
       KMD_1          "Identifica figuras a partir de la descripción de sus atributos geométricos."
       KMD_2          "Ejecuta desplazamientos siguiendo la trayectoria indicada, en una representación gráfica."
       KMD_3          "Resuelve problemas que implican repartir objetos."
       KMD_4          "Ordena colecciones  con base en su numerosidad, en orden descendente."
       KMD_5          "Identifica el uso de números para nombrar un elemento y distinguirlo de otro."
       KMD_6          "Completa un patrón en forma gráfica."
       KME_1          "Resuelve problemas que implican comparar colecciones para  identificar dónde hay más o menos elementos."
       KME_2          "Identifica el orden de los números escritos en un tramo de la serie numérica con un rango del 1 al 10."
       KME_3          "Identifica números por su significado en un portador de texto."
       KME_4          "Ordena longitudes de manera creciente."
       KME_5          "Resuelve problemas que implican quitar objetos a una colección que no exceda de 10 elementos."
       KME_6          "Combina diferentes figuras geométricas para formar otra."
       PV1PM          "Primer valor plausible de Pensamiento Matemático"
       PV2PM          "Segundo valor plausible de Pensamiento Matemático"
       PV3PM          "Tercer valor plausible de Pensamiento Matemático"
       PV4PM          "Cuarto valor plausible de Pensamiento Matemático"
       PV5PM          "Quinto valor plausible de Pensamiento Matemático"
       PV6PM          "Sexto valor plausible de Pensamiento Matemático"
       PV7PM          "Septimo valor plausible de Pensamiento Matemático"
       PV8PM          "Octavo valor plausible de Pensamiento Matemático"
       PV9PM          "Noveno valor plausible de Pensamiento Matemático"
       PV10PM         "Décimo valor plausible de Pensamiento Matemático"
       PV11PM         "Decimoprimero valor plausible de Pensamiento Matemático"
       PV12PM         "Decimosegundo valor plausible de Pensamiento Matemático"
       PV13PM         "Decimotercero valor plausible de Pensamiento Matemático"
       PV14PM         "Decimocuarto valor plausible de Pensamiento Matemático"
       PV15PM         "Decimoquinto valor plausible de Pensamiento Matemático"
       PV16PM         "Decimosexto valor plausible de Pensamiento Matemático"
       PV17PM         "Decimoseptimo valor plausible de Pensamiento Matemático"
       PV18PM         "Decimooctavo valor plausible de Pensamiento Matemático"
       PV19PM         "Decimonoveno valor plausible de Pensamiento Matemático"
       PV20PM         "Vigésimo valor plausible de Pensamiento Matemático"
       PMNVL1         "Niveles de logro del Primer valor plausible de Pensamiento Matemático"
       PMNVL2         "Niveles de logro del Segundo valor plausible de Pensamiento Matemático"
       PMNVL3         "Niveles de logro del Tercer valor plausible de Pensamiento Matemático"
       PMNVL4         "Niveles de logro del Cuart valor plausible de Pensamiento Matemático"
       PMNVL5         "Niveles de logro del Quinto valor plausible de Pensamiento Matemático"
       PMNVL6         "Niveles de logro del Sexto valor plausible de Pensamiento Matemático"
       PMNVL7         "Niveles de logro del Séptimo valor plausible de Pensamiento Matemático"
       PMNVL8         "Niveles de logro del Octavo valor plausible de Pensamiento Matemático"
       PMNVL9         "Niveles de logro del Noveno valor plausible de Pensamiento Matemático"
       PMNVL10        "Niveles de logro del Décimo valor plausible de Pensamiento Matemático"
       PMNVL11        "Niveles de logro del Decimoprimerovalor plausible de Pensamiento Matemático"
       PMNVL12        "Niveles de logro del Decimosegundo valor plausible de Pensamiento Matemático"
       PMNVL13        "Niveles de logro del Decimotercero valor plausible de Pensamiento Matemático"
       PMNVL14        "Niveles de logro del Decimocuarto valor plausible de Pensamiento Matemático"
       PMNVL15        "Niveles de logro del Decimoquinto valor plausible de Pensamiento Matemático"
       PMNVL16        "Niveles de logro del Decimosexto valor plausible de Pensamiento Matemático"
       PMNVL17        "Niveles de logro del Decimoseptimo valor plausible de Pensamiento Matemático"
       PMNVL18        "Niveles de logro del Decimooctavo valor plausible de Pensamiento Matemático"
       PMNVL19        "Niveles de logro del Decimonoveno valor plausible de Pensamiento Matemático"
       PMNVL20        "Niveles de logro del Vigésimo valor plausible de Pensamiento Matemático"
       PMNVLII1       "Alumnos que alcanzan al menos el nivel II de logro del Primer valor plausible de Pensamiento Matemático"
       PMNVLII2       "Alumnos que alcanzan al menos el nivel II de logro del Segundo valor plausible de Pensamiento Matemático"
       PMNVLII3       "Alumnos que alcanzan al menos el nivel II de logro del Tercer valor plausible de Pensamiento Matemático"
       PMNVLII4       "Alumnos que alcanzan al menos el nivel II de logro del Cuarto valor plausible de Pensamiento Matemático"
       PMNVLII5       "Alumnos que alcanzan al menos el nivel II de logro del Quinto valor plausible de Pensamiento Matemático"
       PMNVLII6       "Alumnos que alcanzan al menos el nivel II de logro del Sexto valor plausible de Pensamiento Matemático"
       PMNVLII7       "Alumnos que alcanzan al menos el nivel II de logro del Séptimo valor plausible de Pensamiento Matemático"
       PMNVLII8       "Alumnos que alcanzan al menos el nivel II de logro del Octavo valor plausible de Pensamiento Matemático"
       PMNVLII9       "Alumnos que alcanzan al menos el nivel II de logro del Noveno valor plausible de Pensamiento Matemático"
       PMNVLII10      "Alumnos que alcanzan al menos el nivel II de logro del Décimo valor plausible de Pensamiento Matemático"
       PMNVLII11      "Alumnos que alcanzan al menos el nivel II de logro del Decimoprimerovalor plausible de Pensamiento Matemático"
       PMNVLII12      "Alumnos que alcanzan al menos el nivel II de logro del Decimosegundo valor plausible de Pensamiento Matemático"
       PMNVLII13      "Alumnos que alcanzan al menos el nivel II de logro del Decimotercero valor plausible de Pensamiento Matemático"
       PMNVLII14      "Alumnos que alcanzan al menos el nivel II de logro del Decimocuarto valor plausible de Pensamiento Matemático"
       PMNVLII15      "Alumnos que alcanzan al menos el nivel II de logro del Decimoquinto valor plausible de Pensamiento Matemático"
       PMNVLII16      "Alumnos que alcanzan al menos el nivel II de logro del Decimosexto valor plausible de Pensamiento Matemático"
       PMNVLII17      "Alumnos que alcanzan al menos el nivel II de logro del Decimoséptimo valor plausible de Pensamiento Matemático"
       PMNVLII18      "Alumnos que alcanzan al menos el nivel II de logro del Decimooctavo valor plausible de Pensamiento Matemático"
       PMNVLII19      "Alumnos que alcanzan al menos el nivel II de logro del Decimonoveno valor plausible de Pensamiento Matemático"
       PMNVLII20      "Alumnos que alcanzan al menos el nivel II de logro del Vigésimo valor plausible de Pensamiento Matemático"
       PMNVLIII1      "Alumnos que alcanzan al menos el nivel III de logro del Primer valor plausible de Pensamiento Matemático"
       PMNVLIII2      "Alumnos que alcanzan al menos el nivel III de logro del Segundo valor plausible de Pensamiento Matemático"
       PMNVLIII3      "Alumnos que alcanzan al menos el nivel III de logro del Tercer valor plausible de Pensamiento Matemático"
       PMNVLIII4      "Alumnos que alcanzan al menos el nivel III de logro del Cuarto valor plausible de Pensamiento Matemático"
       PMNVLIII5      "Alumnos que alcanzan al menos el nivel III de logro del Quinto valor plausible de Pensamiento Matemático"
       PMNVLIII6      "Alumnos que alcanzan al menos el nivel III de logro del Sexto valor plausible de Pensamiento Matemático"
       PMNVLIII7      "Alumnos que alcanzan al menos el nivel III de logro del Séptimo valor plausible de Pensamiento Matemático"
       PMNVLIII8      "Alumnos que alcanzan al menos el nivel III de logro del Octavo valor plausible de Pensamiento Matemático"
       PMNVLIII9      "Alumnos que alcanzan al menos el nivel III de logro del Noveno valor plausible de Pensamiento Matemático"
       PMNVLIII10     "Alumnos que alcanzan al menos el nivel III de logro del Décimo valor plausible de Pensamiento Matemático"
       PMNVLIII11     "Alumnos que alcanzan al menos el nivel III de logro del Decimoprimerovalor plausible de Pensamiento Matemático"
       PMNVLIII12     "Alumnos que alcanzan al menos el nivel III de logro del Decimosegundo valor plausible de Pensamiento Matemático"
       PMNVLIII13     "Alumnos que alcanzan al menos el nivel III de logro del Decimotercero valor plausible de Pensamiento Matemático"
       PMNVLIII14     "Alumnos que alcanzan al menos el nivel III de logro del Decimocuarto valor plausible de Pensamiento Matemático"
       PMNVLIII15     "Alumnos que alcanzan al menos el nivel III de logro del Decimoquinto valor plausible de Pensamiento Matemático"
       PMNVLIII16     "Alumnos que alcanzan al menos el nivel III de logro del Decimosexto valor plausible de Pensamiento Matemático"
       PMNVLIII17     "Alumnos que alcanzan al menos el nivel III de logro del Decimoséptimo valor plausible de Pensamiento Matemático"
       PMNVLIII18     "Alumnos que alcanzan al menos el nivel III de logro del Decimooctavo valor plausible de Pensamiento Matemático"
       PMNVLIII19     "Alumnos que alcanzan al menos el nivel III de logro del Decimonoveno valor plausible de Pensamiento Matemático"
       PMNVLIII20     "Alumnos que alcanzan al menos el nivel III de logro del Vigésimo valor plausible de Pensamiento Matemático"
       WVARSTRR       "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
       W_FSTR1        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR2        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR3        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR4        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR5        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR6        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR7        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR8        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR9        "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR10       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR11       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR12       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR13       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR14       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR15       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR16       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR17       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR18       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR19       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR20       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR21       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR22       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR23       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR24       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR25       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR26       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR27       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR28       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR29       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR30       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR31       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR32       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR33       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR34       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR35       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR36       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR37       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR38       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR39       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR40       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR41       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR42       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR43       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR44       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR45       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR46       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR47       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR48       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR49       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR50       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR51       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR52       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR53       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR54       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR55       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR56       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR57       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR58       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR59       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR60       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR61       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR62       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR63       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR64       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR65       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR66       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR67       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR68       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR69       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR70       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR71       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR72       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR73       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR74       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR75       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR76       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR77       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR78       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR79       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR80       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR81       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR82       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR83       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR84       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR85       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR86       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR87       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR88       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR89       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR90       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR91       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR92       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR93       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR94       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR95       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR96       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR97       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR98       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR99       "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       W_FSTR100      "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
       VERSION        "Versión de la base de datos"
.





/***********************************************************************
/* Etiquetas de valores.
/*
/**********************************************************************.

VALUE LABELS
       ID_SERV
                     1      "General Pública"
                     2      "Indígena"
                     3      "Técnica Pública"
                     4      "Telesecundaria"
                     5      "Comunitaria"
                     6      "Privada"/
       RURALIDAD
                     0      "Urbano"
                     1      "Rural"
                     9      "No identificada"/
       SEXO
                     1      "Hombre"
                     2      "Mujer"
                     8      "Respuesta múltiple"
                     9      "Respuesta omitida"/
       EDAD_AC
                     4      "4 años"
                     5      "5 años"
                     6      "6 años"
                     7      "7 años"
                     98     "Respuesta múltiple"
                     99     "Respuesta omitida"/
       MES_NAC
                     1      "Enero"
                     2      "Febrero"
                     3      "Marzo"
                     4      "Abril"
                     5      "Mayo"
                     6      "Junio"
                     7      "Julio"
                     8      "Agosto"
                     9      "Septiembre"
                     10     "Octubre"
                     11     "Noviembre"
                     12     "Diciembre"
                     98     "Respuesta múltiple"
                     99     "Respuesta omitida"/
       EDAD
                     99     "Respuesta omitida"/
       EDAD_ACC
                     1      "5 años o menos"
                     2      "6 años o más"
                     99     "Respuesta omitida"/
       EDAD_AT
                     1      "Edad arriba de la típica"
                     2      "Edad típica"
                     99     "Respuesta omitida"/
       DOCENTE
                     9999   "El docente no respondió el cuadernillo"/
       KMA_1
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMA_2
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMA_3
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMA_4
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMA_5
       KMA_6
       KMA_7
       KMB_1
       KMB_2
       KMB_3
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMB_4
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMB_5
       KMB_6
       KMC_1
       KMC_2
       KMC_3
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMC_4
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMC_5
       KMC_6
       KMC_7
       KMD_1
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMD_2
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMD_3
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMD_4
                     0      "Fallo"
                     1      "Acierto Parcial"
                     2      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       KMD_5
       KMD_6
       KME_1
       KME_2
       KME_3
       KME_4
       KME_5
       KME_6
                     0      "Fallo"
                     1      "Acierto"
                     94     "No se presentó a la evaluación a la que pertenece este reactivo"
                     95     "Reactivo no alcanzado (se considera como no administrado)"
                     97     "Reactivo no administrado (No se incluyó en su cuadernillo de examen)"
                     98     "Respuesta Múltiple"
                     99     "Respuesta Omitida"/
       PMNVL1
       PMNVL2
       PMNVL3
       PMNVL4
       PMNVL5
       PMNVL6
       PMNVL7
       PMNVL8
       PMNVL9
       PMNVL10
       PMNVL11
       PMNVL12
       PMNVL13
       PMNVL14
       PMNVL15
       PMNVL16
       PMNVL17
       PMNVL18
       PMNVL19
       PMNVL20
                     1      "Nivel I"
                     2      "Nivel II"
                     3      "Nivel III"
                     4      "Nivel IV"/
       PMNVLII1
       PMNVLII2
       PMNVLII3
       PMNVLII4
       PMNVLII5
       PMNVLII6
       PMNVLII7
       PMNVLII8
       PMNVLII9
       PMNVLII10
       PMNVLII11
       PMNVLII12
       PMNVLII13
       PMNVLII14
       PMNVLII15
       PMNVLII16
       PMNVLII17
       PMNVLII18
       PMNVLII19
       PMNVLII20
                     0      "Nivel I"
                     1      "Al menos el nivel II"/
       PMNVLIII1
       PMNVLIII2
       PMNVLIII3
       PMNVLIII4
       PMNVLIII5
       PMNVLIII6
       PMNVLIII7
       PMNVLIII8
       PMNVLIII9
       PMNVLIII10
       PMNVLIII11
       PMNVLIII12
       PMNVLIII13
       PMNVLIII14
       PMNVLIII15
       PMNVLIII16
       PMNVLIII17
       PMNVLIII18
       PMNVLIII19
       PMNVLIII20
                     0      "Nivel I y II"
                     1      "Al menos el nivel III"
.
EXECUTE.



/***********************************************************************
/* Valores perdidos.
/*
/**********************************************************************.

MISSING VALUES RURALIDAD (9).
MISSING VALUES SEXO (8,9).
MISSING VALUES EDAD_AC TO EDAD_AT (98,99).
MISSING VALUES DOCENTE (9999).
MISSING VALUES KMA_1 TO KME_6 (94 TO 99).
EXECUTE.
